==> haskell-jwt-0.7.2-43-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-CALeIaan0HP4aPwx6AAvYj
key: jwt-0.7.2-CALeIaan0HP4aPwx6AAvYj
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
indefinite: False
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: be624bc06141757fc17a0ee4e835b6db
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-CALeIaan0HP4aPwx6AAvYj
depends:
    base-4.10.1.0 cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    aeson-1.2.4.0-FhLJrcwJWSLDqhx0AuRAao containers-0.5.10.2
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX time-1.8.0.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I=96c7223eb24ebab9c9677bd383f9a0fa
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=73bd87255495d2259f63e7f9009bea01
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             aeson-1.2.4.0-FhLJrcwJWSLDqhx0AuRAao=83c3b3d90618343923877b4090242cdb
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ=17ff77631878cfceba90438df04f39d6
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jwt-0.7.2-44-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-DQKQfox6bbD7L1P7QBqCd4
key: jwt-0.7.2-DQKQfox6bbD7L1P7QBqCd4
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
indefinite: False
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: 18d5e4816a22261449045838b9469e8f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-DQKQfox6bbD7L1P7QBqCd4
depends:
    base-4.10.1.0 cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF containers-0.5.10.2
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX time-1.8.0.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I=96c7223eb24ebab9c9677bd383f9a0fa
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=73bd87255495d2259f63e7f9009bea01
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI=a27ded325e5d5959c97ff2a5817450bc
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ=17ff77631878cfceba90438df04f39d6
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
